@@ -236,7 +236,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.2.45'
+__version__ = '0.2.47'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -669,30 +669,24 @@ class LiszDataMixin:
         return node
 
     def flow_path_quick_jump_nodes(self) -> List[str]:
-        """ determine nodes relative to the current flow path to quick-jump to from current node.
+        """ determine the current flow paths of all nodes excluding the current, to quick-jump from current node.
 
-        :return:                list of flow path texts.
+        :return:                list of flow path texts of all nodes apart from the current one.
         """
-        def append_nodes(node):
+        paths: List[str] = list()
+        deeper_flow_path: List[str] = list()
+
+        def append_node_path_texts(node):
             """ recursively collect all available nodes (possible flow paths) """
+            if node != self.current_node_items:
+                paths.append(self.flow_path_text(deeper_flow_path, display_root=True))
             for nid in node:
                 if 'node' in nid:
                     deeper_flow_path.append(id_of_flow('enter', 'item', nid['id']))
-                    paths.append(self.flow_path_text(deeper_flow_path))
-                    append_nodes(nid['node'])
+                    append_node_path_texts(nid['node'])
                     deeper_flow_path.pop()
 
-        paths = [FLOW_PATH_ROOT_ID] if self.flow_path_action(path_index=0) == 'enter' else list()
-
-        # add flow path parents up-to/without-already added root
-        deep = 1
-        while deep < len(self.flow_path) and self.flow_path_action(path_index=deep) == 'enter':
-            paths.append(self.flow_path_text(self.flow_path[:deep]))
-            deep += 1
-
-        # add sub paths, find start node from the end of current flow path, skipping opt. open_flow_path_jumper flow id
-        deeper_flow_path = flow_path_strip(self.flow_path)
-        append_nodes(self.current_node_items)
+        append_node_path_texts(self.root_node)
 
         return paths
 
@@ -1003,6 +997,8 @@ class LiszDataMixin:
         event_kwargs['flow_id'] = id_of_flow('focus', 'item', item_id)
         return True
 
+    on_item_sel_confirming = on_item_sel_change     #: confirming sub-list item de-/selection from ItemSelConfirmPopup
+
     def on_key_press(self, modifiers: str, key_code: str) -> bool:
         """  check key press event to be handled and processed as command/action.
 
